@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = '0.9.8';
+our $VERSION = '0.9.10';
 
 print __PACKAGE__.' is version: '.$VERSION.$/ if($ENV{'PDF_TABLE_DEBUG'});
 
@@ -60,7 +60,7 @@ sub set_pdf{
 
 sub set_page{
     my ($self, $page) = @_;
-    if ( ref($page) ne 'PDF::API2::Page' ){
+    if ( defined($page) && ref($page) ne 'PDF::API2::Page' ){
 
         if( ref($self->{'pdf'}) eq 'PDF::API2' ){
             $self->{'page'} = $self->{'pdf'}->page();
@@ -439,10 +439,10 @@ sub table
             # This should fix a bug with very long words like serial numbers etc.
             if( $max_word_len > 0 )
             {
-                $data->[$row_idx][$column_idx] =~ s#(\S{$max_word_len}?)(?=\S)#$1 #g;  
+                $data->[$row_idx][$column_idx] =~ s#(\S{$max_word_len})(?=\S)#$1 #g;
             }
-            
-            # Init cell size limits  
+
+            # Init cell size limits
             $space_w                      = $txt->advancewidth( "\x20" );
             $column_widths->[$column_idx] = 0;
             $max_col_w                    = 0;
